window.Gleam.initSearch([{"doc":"json_canvas","title":"json_canvas","content":"# json_canvas\n\n[![Package Version](https://img.shields.io/hexpm/v/json_canvas)](https://hex.pm/packages/json_canvas)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/json_canvas/)\n\nJSON Canvas library for Gleam\n\nFor more information about JSON Canvas, please refer to &lt;https://jsoncanvas.org/&gt;.\n\n## Installation\n\n```sh\ngleam add json_canvas\n```\n\n## Usage\n\n```gleam\nimport gleam/int\nimport gleam/io\nimport gleam/list\nimport json_canvas\nimport simplifile\n\npub fn main() {\n  let assert Ok(content) = simplifile.read(from: &quot;input.canvas&quot;)\n\n  // Decode a JSON Canvas from a JSON string\n  let assert Ok(canvas) = json_canvas.decode(content)\n\n  let nodes = canvas.nodes\n  let edges = canvas.edges\n\n  io.println(&quot;Node count: &quot; &lt;&gt; int.to_string(list.length(nodes)))\n  io.println(&quot;Edge count: &quot; &lt;&gt; int.to_string(list.length(edges)))\n\n  // Encode a JSON Canvas into a JSON string\n  canvas\n  |&gt; json_canvas.to_string\n  |&gt; simplifile.write(to: &quot;output.canvas&quot;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/json_canvas&gt;.\n\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"json_canvas/types","title":"Canvas","content":"pub type Canvas {\n  Canvas(nodes: List(Node), edges: List(Edge))\n}\n\nCanvas(nodes: List(Node), edges: List(Edge))\n\n\nSynonyms:\njson_canvas/types.Canvas\njson_canvas/types Canvas","url":"json_canvas/types.html#Canvas"},{"doc":"json_canvas/types","title":"Edge","content":"pub type Edge {\n  Edge(\n    id: EdgeId,\n    from_node: NodeId,\n    from_side: Option(Side),\n    from_end: EndpointShape,\n    to_node: NodeId,\n    to_side: Option(Side),\n    to_end: EndpointShape,\n    color: Option(String),\n    label: Option(String),\n  )\n}\n\nEdge(\n  id: EdgeId,\n  from_node: NodeId,\n  from_side: Option(Side),\n  from_end: EndpointShape,\n  to_node: NodeId,\n  to_side: Option(Side),\n  to_end: EndpointShape,\n  color: Option(String),\n  label: Option(String),\n)\n\n\nSynonyms:\njson_canvas/types.Edge\njson_canvas/types Edge","url":"json_canvas/types.html#Edge"},{"doc":"json_canvas/types","title":"EdgeId","content":"pub type EdgeId {\n  EdgeId(String)\n}\n\nEdgeId(String)\n\n\nSynonyms:\njson_canvas/types.EdgeId\njson_canvas/types EdgeId","url":"json_canvas/types.html#EdgeId"},{"doc":"json_canvas/types","title":"EndpointShape","content":"pub type EndpointShape {\n  WithArrow\n  WithoutArrow\n}\n\nWithArrow\n\n\nWithoutArrow\n\n\nSynonyms:\njson_canvas/types.EndpointShape\njson_canvas/types EndpointShape","url":"json_canvas/types.html#EndpointShape"},{"doc":"json_canvas/types","title":"GroupBackgroundStyle","content":"pub type GroupBackgroundStyle {\n  Cover\n  Ratio\n  Repeat\n}\n\nCover\n\n\nRatio\n\n\nRepeat\n\n\nSynonyms:\njson_canvas/types.GroupBackgroundStyle\njson_canvas/types GroupBackgroundStyle","url":"json_canvas/types.html#GroupBackgroundStyle"},{"doc":"json_canvas/types","title":"Node","content":"pub type Node {\n  TextNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(String),\n    text: String,\n  )\n  FileNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(String),\n    path: String,\n    subpath: Option(String),\n  )\n  LinkNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(String),\n    url: String,\n  )\n  GroupNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(String),\n    label: Option(String),\n    background: Option(String),\n    background_style: Option(GroupBackgroundStyle),\n  )\n}\n\nTextNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(String),\n  text: String,\n)\n\n\nFileNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(String),\n  path: String,\n  subpath: Option(String),\n)\n\n\nLinkNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(String),\n  url: String,\n)\n\n\nGroupNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(String),\n  label: Option(String),\n  background: Option(String),\n  background_style: Option(GroupBackgroundStyle),\n)\n\n\nSynonyms:\njson_canvas/types.Node\njson_canvas/types Node","url":"json_canvas/types.html#Node"},{"doc":"json_canvas/types","title":"NodeId","content":"pub type NodeId {\n  NodeId(String)\n}\n\nNodeId(String)\n\n\nSynonyms:\njson_canvas/types.NodeId\njson_canvas/types NodeId","url":"json_canvas/types.html#NodeId"},{"doc":"json_canvas/types","title":"Side","content":"pub type Side {\n  Top\n  Right\n  Bottom\n  Left\n}\n\nTop\n\n\nRight\n\n\nBottom\n\n\nLeft\n\n\nSynonyms:\njson_canvas/types.Side\njson_canvas/types Side","url":"json_canvas/types.html#Side"},{"doc":"json_canvas/types","title":"json_canvas/types","content":"","url":"json_canvas/types.html"},{"doc":"json_canvas","title":"decode","content":"pub fn decode(\n  from json_canvas: String,\n) -&gt; Result(Canvas, DecodeError)\n Decode a JSON Canvas string representation into a `Canvas` value.\nSynonyms:\njson_canvas.decode\njson_canvas decode","url":"json_canvas.html#decode"},{"doc":"json_canvas","title":"to_json","content":"pub fn to_json(canvas: Canvas) -&gt; Json\n Convert a JSON Canvas value into a `gleam/json`&#39;s `Json` value.\nSynonyms:\njson_canvas.to_json\njson_canvas to_json","url":"json_canvas.html#to_json"},{"doc":"json_canvas","title":"to_string","content":"pub fn to_string(canvas: Canvas) -&gt; String\n Convert a JSON Canvas value into a string.\nSynonyms:\njson_canvas.to_string\njson_canvas to_string","url":"json_canvas.html#to_string"},{"doc":"json_canvas","title":"to_string_builder","content":"pub fn to_string_builder(canvas: Canvas) -&gt; StringBuilder\n Convert a JSON Canvas value into a string builder.\nSynonyms:\njson_canvas.to_string_builder\njson_canvas to_string_builder","url":"json_canvas.html#to_string_builder"},{"doc":"json_canvas","title":"json_canvas","content":"","url":"json_canvas.html"}]);